﻿using System;
using System.Diagnostics;
using System.Linq;
using System.Windows;
using ThinkGeo.Core;

namespace Ticket_21784
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Add the WMS layer to the map
        /// </summary>
        private void MapView_Loaded(object sender, RoutedEventArgs e)
        {
            mapView.MapUnit = GeographyUnit.Meter;

            var layer = new GeoTiffRasterLayer(@"..\..\..\ok-tiff\ok-tiff.tif");
            var converter = new UnmanagedProjectionConverter(
                @"+proj=utm +zone=35 +ellps=GRS80 +units=m +no_defs",
                @"+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +wktext +no_defs");

            converter.Open();
            layer.ImageSource.ProjectionConverter = converter;

            OpenStreetMapOverlay osmOverlay = new OpenStreetMapOverlay();
            osmOverlay.TimeoutInSeconds = 600;
            mapView.Overlays.Add(osmOverlay);

            var overlay = new LayerOverlay();
            overlay.Layers.Add(layer);
            mapView.Overlays.Add(overlay);

            layer.Open();

            var bbox = layer.GetBoundingBox();
            Debug.WriteLine(bbox);

            mapView.CurrentExtent = layer.GetBoundingBox();
            mapView.Refresh();
        }

        public void Dispose()
        {
            // Dispose of unmanaged resources.
            mapView.Dispose();
            // Suppress finalization.
            GC.SuppressFinalize(this);
        }
    }
}
